Change parameter names from Stan format to be more human readable

rename_params_from_stan(original_names, data_descriptors)

Arguments

original_names

a character vector of parameter names as they are output by Stan. Tensor parameters are expected to be named as they are in rstan output, e.g. my_matrix[1,2], not as they are named in cmdstan output, e.g. my_matrix.1.2. The latter can be converted to the former using mastiff::rename_params_cmdstanfile_to_rstan().

data_descriptors

a list of things describing the dataset, of the format output by prepare_data_for_stan() (inside its list of outputs).

Value

a character vector containing the renamed parameters, of the same length and in the same order as original_names.