Flattens true parameter values from a list into a vector and renames

wrangle_true_params(param_true_values_list, data_descriptors)

Arguments

param_true_values_list

a list with the true parameter values, in the format output by simulate_data() (inside its list of outputs).

data_descriptors

a list of things describing the dataset, of the format output by prepare_data_for_stan() (inside its list of outputs).

Value

A named numeric vector, with one element per parameter.